"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Button;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _responsive = require("../responsive");
var _Text = require("../texts/Text");
var _useTheme = _interopRequireDefault(require("../useTheme"));
var _View = require("../views/View");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const SIZES = {
  "xs": _responsive.BUTTON_HEIGHT - 10,
  "sm": _responsive.BUTTON_HEIGHT - 5,
  "default": _responsive.BUTTON_HEIGHT,
  "md": _responsive.BUTTON_HEIGHT + 5,
  "lg": _responsive.BUTTON_HEIGHT + 10,
  "xl": _responsive.BUTTON_HEIGHT + 15,
  "2xl": _responsive.BUTTON_HEIGHT + 250
};
function Button({
  children,
  onPress,
  type = "solid",
  textStyle,
  loading,
  disabled,
  size = "default",
  ...rest
}) {
  const {
    colors
  } = (0, _useTheme.default)();
  let styles = {
    height: SIZES[size],
    borderRadius: SIZES[size] / 4.5,
    backgroundColor: type === "solid" ? colors.button : "transparent",
    borderWidth: type === "outlined" ? 0.5 : 0,
    borderColor: type === "outlined" ? colors.border : ""
  };
  if (rest.background) styles.backgroundColor = colors[rest.background];
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: onPress,
    style: [styles, rest],
    disabled: loading || disabled
  }, /*#__PURE__*/_react.default.createElement(_View.View, {
    flex: 1,
    padding: 5,
    paddingHorizontal: 10
  }, /*#__PURE__*/_react.default.createElement(_View.View, {
    flex: 1,
    alignItems: "center",
    justifyContent: "center"
  }, typeof children === "string" ? /*#__PURE__*/_react.default.createElement(_Text.Text, _extends({}, textStyle, {
    weight: "bold"
  }), children) : children, loading && /*#__PURE__*/_react.default.createElement(_View.Center, _responsive.ABSOLUTE_STYLE, /*#__PURE__*/_react.default.createElement(_reactNative.ActivityIndicator, {
    color: colors.buttonText
  })))), disabled && /*#__PURE__*/_react.default.createElement(_View.View, _extends({}, _responsive.ABSOLUTE_STYLE, {
    backgroundColor: "grey",
    opacity: 0.85,
    borderRadius: styles.borderRadius,
    zIndex: -1
  })));
}
//# sourceMappingURL=Button.js.map