"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = FloatTextInput;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _useTheme = _interopRequireDefault(require("../useTheme"));
var _View = require("../views/View");
var _TextInput = _interopRequireWildcard(require("./TextInput"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function FloatTextInput({
  label,
  suffix,
  background,
  containerStyle,
  ...rest
}) {
  const {
    colors,
    fontSizes
  } = (0, _useTheme.default)();
  if (!background) background = "transparent";
  const [isFocused, setIsFcused] = (0, _react.useState)(false);
  let inputHeight = _TextInput.INPUT_SIZES[rest.size || "md"];
  const animationValue = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const handleFocus = e => {
    var _rest$onFocus;
    setIsFcused(true);
    (_rest$onFocus = rest.onFocus) === null || _rest$onFocus === void 0 || _rest$onFocus.call(rest, e);
    _reactNative.Animated.timing(animationValue, {
      toValue: 1,
      duration: 300,
      useNativeDriver: false
    }).start();
    _reactNative.Animated.timing(zIndexValue, {
      toValue: 1,
      duration: 200,
      useNativeDriver: false
    }).start();
  };
  (0, _react.useEffect)(() => {
    if (rest.value === " " || rest.value == "") return;
    if (!isFocused) handleFocus();
  }, [rest.value]);
  const handleBlur = e => {
    var _rest$onBlur;
    (_rest$onBlur = rest.onBlur) === null || _rest$onBlur === void 0 || _rest$onBlur.call(rest, e);
    if (rest.value) return;
    setIsFcused(false);
    _reactNative.Animated.timing(animationValue, {
      toValue: 0,
      duration: 300,
      useNativeDriver: false
    }).start();
    _reactNative.Animated.timing(zIndexValue, {
      toValue: -1,
      duration: 200,
      useNativeDriver: false
    }).start();
  };
  const zIndexValue = (0, _react.useRef)(new _reactNative.Animated.Value(-1)).current;
  const labelStyle = {
    left: 10,
    top: animationValue.interpolate({
      inputRange: [0, 1],
      outputRange: [inputHeight / 3.5, -inputHeight / 5.2]
    }),
    fontSize: animationValue.interpolate({
      inputRange: [0, 1],
      outputRange: [fontSizes.sm, fontSizes.xs]
    }),
    color: colors.text,
    backgroundColor: animationValue.interpolate({
      inputRange: [0, 1],
      outputRange: ["transparent", background]
    }),
    zIndex: zIndexValue.interpolate({
      inputRange: [-1, 1],
      outputRange: [-1, 1]
    })
  };
  return /*#__PURE__*/_react.default.createElement(_View.View, containerStyle, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.Text, {
    style: {
      ...labelStyle,
      position: "absolute",
      fontWeight: "600",
      paddingHorizontal: 2,
      zIndex: labelStyle.zIndex
    }
  }, label), /*#__PURE__*/_react.default.createElement(_TextInput.default, _extends({}, rest, {
    onBlur: handleBlur,
    onFocus: handleFocus
  })), suffix && /*#__PURE__*/_react.default.createElement(_View.Center, {
    position: "absolute",
    right: 10,
    top: 0,
    bottom: 0
  }, suffix));
}
//# sourceMappingURL=FloatTextInput.js.map